@@ -18,8 +18,14 @@ print "ok 1\n";
 # (correspondingly "not ok 13") depending on the success of chunk 13
 # of the test code):
 
-my $test = new File::List("/usr/local");
+my $test = new File::List("/usr/opt");
 
-my @perl_scripts = @{ $test->find("pl\$") };
+#$test->show_empty_dirs();
+my @perl_scripts = @{ $test->find("music") };
 print join("\n",@perl_scripts);
-print "\n";
+print "\n-----------------\n";
+
+$test->show_empty_dirs();
+my @perl_scripts = @{ $test->find("music") };
+print join("\n",@perl_scripts);
+print "\n-----------------\n"; 
